#!/bin/ksh
# %Z% %M%
# %I% %W%
# %E% %U%
###############################################################################
#
# This script is used to install the TBSM Adapter software for NetView.  This
# script expects, as input, the name of a tar file that contains all of the
# TBSM files (executables, scripts, configuration files, etc.) in a usr/OV tree
# structure, and will lay down and configure the tar file contents.  If the tar
# file is not given as input, it expects it to be in the current directory with
# the name of IMfNetView.tar.
#
# Output, by default, is sent to the process running the install script.
#
###############################################################################
#				Functions
###############################################################################
#
#--------------------------------------------------------------------
# ReportMSG - report a message to the user.
#--------------------------------------------------------------------
#
ReportMSG()
{
    echo "$THISCRPT (`date +%T`): $*"
}
#
#--------------------------------------------------------------------
# Difference - determine if a given file meets criteria to be saved.
#--------------------------------------------------------------------
#
Difference()
{
    [ ! -f $1 ]  &&  return 1	# Make sure actual file exists
    [ ! -f $2 ]  &&  return 1   # Make sure new file exists

    diff $1 $2 1>/dev/null 2>&1

    [ $? -ne 1 ] &&  return 1   # Make sure they are different

    return 0
}
#
###############################################################################
#			    Start of Main Program
###############################################################################
#
#--------------------------------------------------------------------
# Set environment variables and environment
#--------------------------------------------------------------------
#
THISCRPT=`basename $0`
TARFILE=${1:-IMfNetView.tar}
HERE=`pwd`
STATUS=0
#
#--------------------------------------------------------------------
# Check to make sure we're root; otherwise, we can't do this.
#--------------------------------------------------------------------
#
if [ "`whoami`" != "root" ]; then
   ReportMSG "You must be the root user to install this kit."
   STATUS=1
fi
#
#--------------------------------------------------------------------
# Check to make sure we can find the tar file, and if so, untar it.
#--------------------------------------------------------------------
#
if [ $STATUS = 0 ]; then

   if [ ! -f $TARFILE ]; then

      ReportMSG "Unable to find tar file $TARFILE to process."
      STATUS=1

   else 

      ReportMSG "Installation of the TBSM Intelligent Monitor for NetView started..."

      if [ "`uname`" = "AIX" ] ; then
         /usr/sbin/slibclean
      fi

      cd / 1>/dev/null 2>&1
      tar -xf $HERE/$TARFILE

      if [ $? -eq 0 ]; then
         ReportMSG "TBSM Intelligent Monitor software loaded correctly."
      else
         ReportMSG "Unable to load TBSM Intelligent Monitor software."
         STATUS=2
      fi

      cd - 1>/dev/null 2>&1

   fi
fi
#
#--------------------------------------------------------------------
# If it unloaded correctly, save any customized files if they exist.
#--------------------------------------------------------------------
#
if [ $STATUS = 0 ]; then

   FILELIST="/usr/OV/conf/topxignore.conf   /usr/OV/conf/topxfieldmap.conf \
             /usr/OV/conf/topxclassmap.conf /usr/OV/conf/topxtrapgate.conf \
             /usr/OV/conf/nvid.conf /usr/OV/conf/topxtbsmagent.properties \
             /usr/OV/conf/topxlistener.properties /usr/OV/lrf/tbsmadapter.lrf"

   for OLDFILE in $FILELIST
   do

       NAME=`basename $OLDFILE`
       NEWFILE="/usr/OV/newconfig/tbsm/$NAME"

       if Difference $OLDFILE $NEWFILE; then
          cp -p $OLDFILE $OLDFILE.old
          ReportMSG "Previous file $OLDFILE saved as $OLDFILE.old"
       fi

       [ -f $NEWFILE ]  &&  cp -p $NEWFILE $OLDFILE

   done
fi
#
#--------------------------------------------------------------------
# If everything has gone correctly, do the ovaddobj (if needed).
#--------------------------------------------------------------------
#
if [ $STATUS = 0 ]; then

   grep tbsmadapter /usr/OV/conf/ovsuf | grep "^0:"

   if [ $? -ne 0 ]; then

      if [ ! -f /usr/OV/lrf/tbsmadapter.lrf ]; then

         ReportMSG "Unable to find TBSM Intelligent Monitor license registration file."
         STATUS=4

      else

         /usr/OV/bin/ovaddobj /usr/OV/lrf/tbsmadapter.lrf

         if [ $? = 0 ]; then
            ReportMSG "TBSM Intelligent Monitor daemon successfully added to NetView Configuration."
         else
            ReportMSG "Unable to add TBSM Intelligent Monitor daemon to NetView Configuration."
            STATUS=5
         fi
      fi
   fi
fi
#
#--------------------------------------------------------------------
# Report to the user whether patch was added successfully or not.
#--------------------------------------------------------------------
#
if [ $STATUS = 0 ]; then
   ReportMSG "Installation of TBSM Intelligent Monitor for Netview was successful."
else
   ReportMSG "Installation of TBSM Intelligent Monitor for NetView failed."
fi

return $STATUS
#
###############################################################################
#			     End of Main Program
###############################################################################
